==> aliyun-python-sdk-mse-3.0.11.tar.gz: aliyun-python-sdk-mse-3.0.11/aliyunsdkmse/request/v20190531/AddMockRuleRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkmse.endpoint import endpoint_data

class AddMockRuleRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'mse', '2019-05-31', 'AddMockRule')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_ExtraJson(self): # String
		return self.get_query_params().get('ExtraJson')

	def set_ExtraJson(self, ExtraJson):  # String
		self.add_query_param('ExtraJson', ExtraJson)
	def get_ProviderAppId(self): # String
		return self.get_query_params().get('ProviderAppId')

	def set_ProviderAppId(self, ProviderAppId):  # String
		self.add_query_param('ProviderAppId', ProviderAppId)
	def get_Source(self): # String
		return self.get_query_params().get('Source')

	def set_Source(self, Source):  # String
		self.add_query_param('Source', Source)
	def get_Enable(self): # Boolean
		return self.get_query_params().get('Enable')

	def set_Enable(self, Enable):  # Boolean
		self.add_query_param('Enable', Enable)
	def get_ScMockItems(self): # String
		return self.get_query_params().get('ScMockItems')

	def set_ScMockItems(self, ScMockItems):  # String
		self.add_query_param('ScMockItems', ScMockItems)
	def get_ProviderAppName(self): # String
		return self.get_query_params().get('ProviderAppName')

	def set_ProviderAppName(self, ProviderAppName):  # String
		self.add_query_param('ProviderAppName', ProviderAppName)
	def get_ConsumerAppIds(self): # String
		return self.get_query_params().get('ConsumerAppIds')

	def set_ConsumerAppIds(self, ConsumerAppIds):  # String
		self.add_query_param('ConsumerAppIds', ConsumerAppIds)
	def get_DubboMockItems(self): # String
		return self.get_query_params().get('DubboMockItems')

	def set_DubboMockItems(self, DubboMockItems):  # String
		self.add_query_param('DubboMockItems', DubboMockItems)
	def get_Name(self): # String
		return self.get_query_params().get('Name')

	def set_Name(self, Name):  # String
		self.add_query_param('Name', Name)
	def get_AcceptLanguage(self): # String
		return self.get_query_params().get('AcceptLanguage')

	def set_AcceptLanguage(self, AcceptLanguage):  # String
		self.add_query_param('AcceptLanguage', AcceptLanguage)
	def get_MockType(self): # Long
		return self.get_query_params().get('MockType')

	def set_MockType(self, MockType):  # Long
		self.add_query_param('MockType', MockType)
	def get_Region(self): # String
		return self.get_query_params().get('Region')

	def set_Region(self, Region):  # String
		self.add_query_param('Region', Region)

==> aliyun-python-sdk-mse-3.0.19.tar.gz: aliyun-python-sdk-mse-3.0.19/aliyunsdkmse/request/v20190531/AddMockRuleRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkmse.endpoint import endpoint_data

class AddMockRuleRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'mse', '2019-05-31', 'AddMockRule','mse')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_ExtraJson(self): # String
		return self.get_query_params().get('ExtraJson')

	def set_ExtraJson(self, ExtraJson):  # String
		self.add_query_param('ExtraJson', ExtraJson)
	def get_ProviderAppId(self): # String
		return self.get_query_params().get('ProviderAppId')

	def set_ProviderAppId(self, ProviderAppId):  # String
		self.add_query_param('ProviderAppId', ProviderAppId)
	def get_Source(self): # String
		return self.get_query_params().get('Source')

	def set_Source(self, Source):  # String
		self.add_query_param('Source', Source)
	def get_Enable(self): # Boolean
		return self.get_query_params().get('Enable')

	def set_Enable(self, Enable):  # Boolean
		self.add_query_param('Enable', Enable)
	def get_ScMockItems(self): # String
		return self.get_query_params().get('ScMockItems')

	def set_ScMockItems(self, ScMockItems):  # String
		self.add_query_param('ScMockItems', ScMockItems)
	def get_ProviderAppName(self): # String
		return self.get_query_params().get('ProviderAppName')

	def set_ProviderAppName(self, ProviderAppName):  # String
		self.add_query_param('ProviderAppName', ProviderAppName)
	def get_ConsumerAppIds(self): # String
		return self.get_query_params().get('ConsumerAppIds')

	def set_ConsumerAppIds(self, ConsumerAppIds):  # String
		self.add_query_param('ConsumerAppIds', ConsumerAppIds)
	def get_DubboMockItems(self): # String
		return self.get_query_params().get('DubboMockItems')

	def set_DubboMockItems(self, DubboMockItems):  # String
		self.add_query_param('DubboMockItems', DubboMockItems)
	def get_Name(self): # String
		return self.get_query_params().get('Name')

	def set_Name(self, Name):  # String
		self.add_query_param('Name', Name)
	def get_AcceptLanguage(self): # String
		return self.get_query_params().get('AcceptLanguage')

	def set_AcceptLanguage(self, AcceptLanguage):  # String
		self.add_query_param('AcceptLanguage', AcceptLanguage)
	def get_MockType(self): # Long
		return self.get_query_params().get('MockType')

	def set_MockType(self, MockType):  # Long
		self.add_query_param('MockType', MockType)
	def get_Region(self): # String
		return self.get_query_params().get('Region')

	def set_Region(self, Region):  # String
		self.add_query_param('Region', Region)
